@@ -1,48 +1,3 @@
-#' Clustering by fast search and find of density peaks
-#'
-#' This package implement the clustering algorithm described by Alex Rodriguez
-#' and Alessandro Laio (2014). It provides the user with tools for generating
-#' the initial rho and delta values for each observation as well as using these
-#' to assign observations to clusters. This is done in two passes so the user is
-#' free to reassign observations to clusters using a new set of rho and delta
-#' thresholds, without needing to recalculate everything.
-#'
-#' @section Plotting:
-#' Two types of plots are supported by this package, and both mimics the types of
-#' plots used in the publication for the algorithm. The standard plot function
-#' produces a decision plot, with optional colouring of cluster peaks if these
-#' are assigned. Furthermore [plotMDS()] performs a multidimensional
-#' scaling of the distance matrix and plots this as a scatterplot. If clusters
-#' are assigned observations are coloured according to their assignment.
-#'
-#' @section Cluster detection:
-#' The two main functions for this package are [densityClust()] and
-#' [findClusters()]. The former takes a distance matrix and optionally
-#' a distance cutoff and calculates rho and delta for each observation. The
-#' latter takes the output of [densityClust()] and make cluster
-#' assignment for each observation based on a user defined rho and delta
-#' threshold. If the thresholds are not specified the user is able to supply
-#' them interactively by clicking on a decision plot.
-#'
-#' @examples
-#' irisDist <- dist(iris[,1:4])
-#' irisClust <- densityClust(irisDist, gaussian=TRUE)
-#' plot(irisClust) # Inspect clustering attributes to define thresholds
-#'
-#' irisClust <- findClusters(irisClust, rho=2, delta=2)
-#' plotMDS(irisClust)
-#' split(iris[,5], irisClust$clusters)
-#'
-#' @seealso [densityClust()], [findClusters()], [plotMDS()]
-#' @aliases NULL
-#'
-#' @references Rodriguez, A., & Laio, A. (2014). *Clustering by fast search and find of density peaks.* Science, **344**(6191), 1492-1496. doi:10.1126/science.1242072
-#'
-#' @useDynLib densityClust
-#' @importFrom Rcpp sourceCpp
-#' 
-'_PACKAGE'
-
 #' Computes the local density of points in a distance matrix
 #'
 #' This function takes a distance matrix and a distance cutoff and calculate the
@@ -94,7 +49,7 @@ localDensity <- function(distance, dc, gaussian = FALSE) {
 distanceToPeak <- function(distance, rho) {
   # This implementation is faster by virtue of being written in C++.
   # It also avoids the need to convert `distance` to a matrix.
-  res <- distanceToPeakCpp(distance, rho);
+  res <- distanceToPeakCpp(as.numeric(distance), as.numeric(rho));
   names(res) <- names(rho)
   res
 }
@@ -534,7 +489,7 @@ findClusters.densityCluster <- function(x, rho, delta, plot = FALSE, peaks = NUL
         cluster[i] <- match(i, x$peaks)
       } else {
         higherDensity <- which(x$rho > x$rho[i])
-        cluster[i] <- cluster[higherDensity[which.min(findDistValueByRowColInd(x$distance, attr(x$distance, 'Size'), i, higherDensity))]] 
+        cluster[i] <- cluster[higherDensity[which.min(findDistValueByRowColInd(as.numeric(x$distance), as.integer(attr(x$distance, 'Size')), i, higherDensity))]] 
       }
     }
     x$clusters <- cluster
@@ -546,7 +501,7 @@ findClusters.densityCluster <- function(x, rho, delta, plot = FALSE, peaks = NUL
       if (verbose) message('the current index of the peak is ', i)
       
       averageRho <- outer(x$rho[cluster == i], x$rho[cluster != i], '+')/2 
-      index <- findDistValueByRowColInd(x$distance, attr(x$distance, 'Size'), which(cluster == i), which(cluster != i)) <= x$dc 
+      index <- findDistValueByRowColInd(as.numeric(x$distance), as.integer(attr(x$distance, 'Size')), which(cluster == i), which(cluster != i)) <= x$dc 
       if (any(index)) border[i] <- max(averageRho[index]) 
     }
     x$halo <- x$rho < border[cluster] 
