@@ -1,12 +1,12 @@
+#include <cpp11/doubles.hpp>
 
-#include <Rcpp.h>
-using namespace Rcpp;
-
-// [[Rcpp::export]]
-NumericVector distanceToPeakCpp(NumericVector distance, NumericVector rho) {
+[[cpp11::register]]
+cpp11::writable::doubles distanceToPeakCpp(cpp11::doubles distance, cpp11::doubles rho) {
   int size = rho.size();
-  NumericVector peaks(size);
-  NumericVector maximum(size);
+  cpp11::writable::doubles peaks(size);
+  std::fill(peaks.begin(), peaks.end(), 0.0);
+  cpp11::writable::doubles maximum(size);
+  std::fill(maximum.begin(), maximum.end(), 0.0);
   
   int i = 0;
   for (int col = 0; col < size; col++) {
@@ -38,7 +38,7 @@ NumericVector distanceToPeakCpp(NumericVector distance, NumericVector rho) {
   
   for (int j = 0; j < size; j++) {
     if (peaks[j] == 0) {
-      peaks[j] = maximum[j];
+      peaks[j] = double(maximum[j]);
     } else {
       // do nothing, peaks is already min
     }
